import 'package:flutter/material.dart';

class PanicDrawer extends StatefulWidget {
  final CircleAvatar currentAccountPicture;

  final Text accountName;
  final Text accountEmail;

  final ImageProvider<dynamic> headerImage;
  final AlignmentGeometry headerImageAlignment;
  final double headerImageScale;

  final List<Widget> items;
  final List<Widget> detailItems;

  const PanicDrawer({
    Key key,
    this.currentAccountPicture,
    this.accountName,
    this.accountEmail,
    this.headerImage,
    this.headerImageAlignment,
    this.headerImageScale = 5.3,
    this.items = const [],
    this.detailItems = const [],
  }) : super(key: key);

  @override
  _PanicDrawerState createState() => _PanicDrawerState();
}

class _PanicDrawerState extends State<PanicDrawer> {
  bool _detailsShown;

  @override
  void initState() {
    _detailsShown = false;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Drawer(
      child: Column(
        children: [
          _buildDrawerHeader(),
          Expanded(
            child: _buildDrawerBody(),
          ),
        ],
      ),
    );
  }

  Widget _buildDrawerHeader() {
    return UserAccountsDrawerHeader(
      onDetailsPressed: () {
        setState(() {
          _detailsShown = !_detailsShown;
        });
      },
      currentAccountPicture: widget.currentAccountPicture,
      accountName: widget.accountName,
      accountEmail: widget.accountEmail,
      margin: EdgeInsets.zero,
      decoration: BoxDecoration(
        color: Theme.of(context).primaryColor,
        image: _buildDrawerHeaderImage(),
      ),
    );
  }

  DecorationImage _buildDrawerHeaderImage() {
    return DecorationImage(
      image: widget.headerImage,
      fit: BoxFit.none,
      alignment: widget.headerImageAlignment ??
          Alignment.lerp(
            Alignment.lerp(Alignment.topCenter, Alignment.bottomCenter, 0.38),
            Alignment.lerp(Alignment.topRight, Alignment.bottomRight, 0.38),
            0.8,
          ),
      scale: widget.headerImageScale,
    );
  }

  Widget _buildDrawerBody() {
    return Column(
      children: [
        _buildDrawerDetails(context),
        Expanded(
          child: _buildDrawerItems(),
        )
      ],
    );
  }

  Widget _buildDrawerDetails(BuildContext context) {
    ThemeData t = Theme.of(context);

    return AnimatedCrossFade(
      firstCurve: const Interval(0.0, 0.6, curve: Curves.fastOutSlowIn),
      secondCurve: const Interval(0.4, 1.0, curve: Curves.fastOutSlowIn),
      sizeCurve: Curves.fastOutSlowIn,
      crossFadeState: _detailsShown ? CrossFadeState.showSecond : CrossFadeState.showFirst,
      duration: Duration(milliseconds: 500),
      firstChild: Container(height: 0.0),
      secondChild: Container(
        color: t.primaryColor.withOpacity(0.8),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: widget.detailItems,
        ),
      ),
    );
  }

  Widget _buildDrawerItems() {
    return ListView(
      padding: EdgeInsets.zero,
      children: widget.items,
    );
  }
}
